#!/bin/sh
#
#

# load standard functions
. scripts/functions
. scripts/cfg-local

CONFIG_FILE=floppy/coyote.cfg

clear
echo
echo "Coyote floppy builder script v2.8"
echo

if ! [ "$UID" = "0" ]; then
	echo "You should be logged in as root to create the Coyote floppy disk. Non-root users"
	echo "can experience permission problems under some distributions when attempting to"
	echo "access the floppy drive.  To cancel, press CTRL-C... to proceed, press enter"
	read JUNK
fi

reset_all

if [ "$1" = "-i" ]; then
	if [ ! -r flp.img ]; then
		echo "Floppy image update specified but no floppy image is present."
		exit 1
	fi
	DOFMT=NO
	DOIMG=YES
	FDCAPACITY=1440
    	FLOPPY=/dev/fd0u1440
else
    DOIMG=NO
    echo "Please choose the desired capacity for the created floppy:"
    echo
    echo "1) 1.44Mb (Safest and most reliable but may lack space needed for"
    echo "           some options)"
    echo "2) 1.68Mb (Good reliability with extra space) - recommended"
    echo "3) 1.72Mb (Most space but may not work on all systems or with all" 
    echo "           diskettes)"
    echo
    echo -n "Enter selection: "
    read FDCAP

    case $FDCAP in
    	1) FDCAPACITY=1440
    		if [ -a /dev/fd0u1440 ]; then
    			FLOPPY=/dev/fd0u1440
    		elif [ -a /dev/fd0H1440 ]; then
    			FLOPPY=/dev/fd0H1440
    		elif [ -a /dev/fd0h1440 ]; then
    			FLOPPY=/dev/fd0h1440
    		else
    			# No device available... try using a built-in
    			FLOPPY=data/dev/fd0u1440
    		fi			
    	   	;;
    	2) FDCAPACITY=1680
    		if [ -a /dev/fd0u1680 ]; then
    			FLOPPY=/dev/fd0u1680
    		else
    			FLOPPY=data/dev/fd0u1680
    		fi
    	   ;;
    	3) FDCAPACITY=1722
    		if [ -a /dev/fd0u1722 ]; then
    			FLOPPY=/dev/fd0u1722
    		else
    			FLOPPY=data/dev/fd0u1722
    		fi
    	   ;;
    	*) echo "Invalid capacity selection."
    	   exit
    	   ;;
    esac	
    if [ "$1" = "-n" ]; then
    	DOFMT=NO
    else
	DOFMT=YES
    fi
fi

echo
echo "Please select the processor type in the destination Coyote Linux"
echo "system:"
echo
echo "1) 386sx, 386dx, 486sx (No math co-processor)"
echo "2) 486dx or better (has a math co-processor)"
echo
echo -n "Enter Selection: "
read PROCTYPE

case $PROCTYPE in
	1)	ln -s data/kernel-nofpu/drivers drivers
		ln -s ../data/kernel-nofpu/floppy/linux floppy/linux
		;;
	2)	ln -s data/kernel-fpu/drivers drivers
		ln -s ../data/kernel-fpu/floppy/linux floppy/linux
		;;
	*)	echo "Invalid selection."
		exit
		;;
esac

# Serial console additions - Currently broken - do not use
#CONSOLEDEV=tty0

# echo
#echo "!! -- NOTE: The following option is experimental -- !!"
#echo "If you would like to use a serial port instead of the default VGA card,"
#echo "you can enable the serial port console mode.  To do so, please enter the"
#echo "name of the device that you wish to use here, omitting the /dev/ prefix."
#echo "To leave the VGA display as the default console, simply press enter. "
#echo 
#echo "For example, enter 'ttyS0' for COM1, 'ttyS1' for COM2, etc."
#echo
#echo -n "Console device: "
#read NEW_CONSOLEDEV
#[ -z "$NEW_CONSOLEDEV" ] || CONSOLEDEV=$NEW_CONSOLEDEV

echo
echo "Please select the type of Internet connection that your system uses."
echo
echo "1) Standard Ethernet Connection"
echo "2) PPP over Ethernet Connection"
echo "3) PPP Dialup Connection"
echo
echo -n "Enter Selection: "
read CONNTYPE

case $CONNTYPE in
	1)	. scripts/mkflp-ethernet
		;;
	2)	. scripts/mkflp-pppoe
		;;
	3)	. scripts/mkflp-ppp
		;;
	*)	echo "'$CONNTYPE' is not a valid option."
		;;
esac

